Point

Struct Point 

pub struct Point { /* private fields */ }
A 2D point with x and y coordinates, each carrying their own unit of measurement.

Implementations

Source

impl Point

pub const fn integer(x: i32, y: i32, units: f64) -> Self

Creates a point with integer coordinates and the given units.

pub const fn float(x: f64, y: f64, units: f64) -> Self

Creates a point with float coordinates and the given units.

pub fn origin() -> Self

Creates a point at the origin (0, 0) with default integer units.

pub const fn default_integer(x: i32, y: i32) -> Self

Creates a point with integer coordinates and default integer units (1e-9).

pub const fn default_float(x: f64, y: f64) -> Self

Creates a point with float coordinates and default float units (1e-6).

pub const fn new(x: Unit, y: Unit) -> Self

Create a point with two arbitrary units.

This is useful for when you want to create a point with different units. This is not highly recommended.

pub const fn units(&self) -> (f64, f64)

Returns the units for both coordinates as (x_units, y_units).

pub const fn set_units(&self, units: f64) -> Self

Returns a copy of this point with both coordinates set to the given units (without scaling).

pub fn scale_units(&self, new_units: f64) -> Self

Returns a copy of this point with both coordinates scaled to the given units.

pub const fn x(&self) -> Unit

Gets the x coordinate of the point.

pub const fn y(&self) -> Unit

Gets the y coordinate of the point.

pub const fn set_x(&mut self, x: Unit)

Sets the x coordinate of the point.

pub const fn set_y(&mut self, y: Unit)

Sets the y coordinate of the point.

pub fn to_integer_unit(&self) -> Self

Converts both coordinates to integer units.

Returns

A new Point with both x and y coordinates converted to Unit::Integer

pub fn to_float_unit(&self) -> Self

Converts both coordinates to float units.

Returns

A new Point with both x and y coordinates converted to Unit::Float

pub fn rotate_around_point(&self, angle: AngleInRadians, center: &Self) -> Self

Rotates the point around an arbitrary center point by the given angle in radians.

Arguments
  • center - The center point to rotate around
  • angle - The rotation angle in radians (positive = counter-clockwise)
Returns

A new Point representing the rotated position