pub struct Point { /* private fields */ }Expand description
A 2D point with x and y coordinates, each carrying their own unit of measurement.
Implementations
Sourceimpl Point
impl Point
Sourcepub const fn integer(x: i32, y: i32, units: f64) -> Self
pub const fn integer(x: i32, y: i32, units: f64) -> Self
Creates a point with integer coordinates and the given units.
Sourcepub const fn float(x: f64, y: f64, units: f64) -> Self
pub const fn float(x: f64, y: f64, units: f64) -> Self
Creates a point with float coordinates and the given units.
Sourcepub const fn default_integer(x: i32, y: i32) -> Self
pub const fn default_integer(x: i32, y: i32) -> Self
Creates a point with integer coordinates and default integer units (1e-9).
Sourcepub const fn default_float(x: f64, y: f64) -> Self
pub const fn default_float(x: f64, y: f64) -> Self
Creates a point with float coordinates and default float units (1e-6).
Sourcepub const fn new(x: Unit, y: Unit) -> Self
pub const fn new(x: Unit, y: Unit) -> Self
Create a point with two arbitrary units.
This is useful for when you want to create a point with different units. This is not highly recommended.
Sourcepub const fn units(&self) -> (f64, f64)
pub const fn units(&self) -> (f64, f64)
Returns the units for both coordinates as (x_units, y_units).
Sourcepub const fn set_units(&self, units: f64) -> Self
pub const fn set_units(&self, units: f64) -> Self
Returns a copy of this point with both coordinates set to the given units (without scaling).
Sourcepub fn scale_units(&self, new_units: f64) -> Self
pub fn scale_units(&self, new_units: f64) -> Self
Returns a copy of this point with both coordinates scaled to the given units.
Sourcepub fn to_integer_unit(&self) -> Self
pub fn to_integer_unit(&self) -> Self
Converts both coordinates to integer units.
Returns
A new Point with both x and y coordinates converted to Unit::Integer
Sourcepub fn to_float_unit(&self) -> Self
pub fn to_float_unit(&self) -> Self
Converts both coordinates to float units.
Returns
A new Point with both x and y coordinates converted to Unit::Float
Sourcepub fn rotate_around_point(&self, angle: AngleInRadians, center: &Self) -> Self
pub fn rotate_around_point(&self, angle: AngleInRadians, center: &Self) -> Self